import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';

export default class CurrentValueDotComponent extends Component {
  @tracked svg;

  // CONFIG
  get color() {
    return this.args.color || 'black';
  }

  get radius() {
    return this.args.radius || 2.5;
  }

  get yKey() {
    return this.args.yKey || 'SUM';
  }

  get xKey() {
    return this.args.xKey || 'OCCURED';
  }

  // COMPUTED
  get noData() {
    return !this.args.dataset || !this.args.dataset.length;
  }

  get datapoint() {
    return this.noData
      ? null
      : this.args.dataset[this.args.dataset.length - 1];
  }

  get dimensions() {
    return this.svg ? this.svg.getBoundingClientRect() : {};
  }

  findSvg = (el) => {
    this.svg = el.closest('svg');
  }

  // Returns x, y coordinates of dot
  // returns {x: , y: }
  get location() {
    if (this.noData || !this.svg) return { x: -100, y: -100 };
    return {
      x: this.args.xScale(new Date(this.datapoint[this.xKey])),
      y: this.args.yScale(this.datapoint[this.yKey])
    }
  }

  findSlope() {
    if (!this.args.dataset || this.args.dataset.length < 2) return 1;
    const datapointTwo = this.args.dataset[this.args.dataset.length - 2];
    const x1 = this.args.xScale(new Date(datapointTwo[this.xKey]));
    const x2 = this.args.xScale(new Date(this.datapoint[this.xKey]));
    const y1 = this.args.yScale(datapointTwo[this.yKey]);
    const y2 = this.args.yScale(this.datapoint[this.yKey]);
    return (y2 - y1) / (x2 - x1);
  }
}
